@@ -1,5 +1,4 @@
 package Pegex::Compiler;
-$Pegex::Compiler::VERSION = '0.32';
 use Pegex::Base;
 
 use Pegex::Parser;
@@ -181,6 +180,7 @@ sub to_perl {
     my $perl = Data::Dumper::Dumper($self->tree);
     $perl =~ s/\?\^:/?-xism:/g;
     $perl =~ s!(\.rgx.*?qr/)\(\?-xism:(.*)\)(?=/)!$1$2!g;
+    $perl =~ s!/u$!/!gm; # new perls put /u, old perls don't understand
     die "to_perl failed with non compatible regex in:\n$perl"
         if $perl =~ /\?\^/;
     return $perl;
